aboutsummaryrefslogtreecommitdiff
path: root/src/lib/crypto/krb/combine_keys.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/crypto/krb/combine_keys.c')
-rw-r--r--src/lib/crypto/krb/combine_keys.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/crypto/krb/combine_keys.c b/src/lib/crypto/krb/combine_keys.c
index acfb99b..0cf3f6f 100644
--- a/src/lib/crypto/krb/combine_keys.c
+++ b/src/lib/crypto/krb/combine_keys.c
@@ -137,14 +137,14 @@ krb5int_c_combine_keys(krb5_context context, krb5_keyblock *key1,
/*
* Concatenate the two keys together, and then run them through
* n-fold to reduce them to a length appropriate for the random-to-key
* operation. Note here that krb5_nfold() takes sizes in bits, hence
* the multiply by 8.
*/
memcpy(combined, r1, keybytes);
memcpy(combined + keybytes, r2, keybytes);
- krb5_nfold((keybytes * 2) * 8, combined, keybytes * 8, rnd);
+ krb5int_nfold((keybytes * 2) * 8, combined, keybytes * 8, rnd);
/*
* Run the "random" bits through random-to-key to produce a encryption
@@ -190,7 +190,7 @@ krb5int_c_combine_keys(krb5_context context, krb5_keyblock *key1,
myalloc = TRUE;
}
- ret = krb5_derive_keyblock(enc, tkey, outkey, &input);
+ ret = krb5int_derive_keyblock(enc, tkey, outkey, &input);
if (ret) {
if (myalloc) {
free(outkey->contents);
@@ -248,7 +248,7 @@ dr(const struct krb5_enc_provider *enc, const krb5_keyblock *inkey,
if (in_constant->length == inblock.length) {
memcpy(inblock.data, in_constant->data, inblock.length);
} else {
- krb5_nfold(in_constant->length*8, (unsigned char *) in_constant->data,
+ krb5int_nfold(in_constant->length*8, (unsigned char *) in_constant->data,
inblock.length*8, (unsigned char *) inblock.data);
}
@@ -137,14 +137,14 @@ krb5int_c_combine_keys(krb5_context context, krb5_keyblock *key1,
* Concatenate the two keys together, and then run them through
* n-fold to reduce them to a length appropriate for the random-to-key
- * operation. Note here that krb5_nfold() takes sizes in bits, hence
+ * operation. Note here that krb5int_nfold() takes sizes in bits, hence
* the multiply by 8.
*/